@@ -67,14 +67,18 @@ def PlotComparative(Calculated, Targeted):
         plt.title('Comparison chart calculated variable vs targeted')
         plt.xlabel('Sequence of events')
         plt.ylabel('Target and predicted variable ' + str(j+1))
-        plt.plot(eixoX, eixoY1, marker = '', color = 'darkblue', label='Targeted')  
-        plt.plot(eixoX, eixoY2, marker = '', color = 'orangered', label='Calculated')
+        plt.plot(eixoX, eixoY1, marker = '', label='Targeted')  
+        plt.plot(eixoX, eixoY2, marker = '', label='Calculated')
+        #plt.plot(eixoX, eixoY2, c='black', marker = '.', label='Calculated', alpha=0.33)
         plt.legend(loc = "upper left")
         plt.show()
 
 
 
 
+
+
+
 #Plot the differences of two variables in a sequential series
 def PlotComparative2(Calculated, Targeted):
 
@@ -98,6 +102,45 @@ def PlotComparative2(Calculated, Targeted):
 
 
 
+
+
+#Plot two variables ifferences in a sequential series com as faixas de erro conf desvio padrão
+def PlotComparative3(Calculated, Targeted):
+
+    numdata,numevar = Calculated.shape
+    eixoX = np.arange(0, numdata, dtype=int)
+
+    for j in range(0,numevar):    
+        eixoY1= Targeted[:,j]
+        eixoY2= Calculated[:,j]
+
+        # Cálculo do erro médio e desvio padrão
+        erro_medio = np.mean(eixoY2 - eixoY1)
+        sigma = np.std(eixoY2 - eixoY1)
+    
+        plt.figure(figsize=(12, 5))
+        plt.title('Comparison chart calculated variable vs targeted')
+        plt.xlabel('Sequence of events')
+        plt.ylabel('Target and predicted variable ' + str(j+1))
+        plt.plot(eixoX, eixoY1, marker = '',  label='Targeted')  
+        plt.plot(eixoX, eixoY2, linestyle='none', c='black', marker = '.', label='Calculated', alpha=0.33)
+        plt.legend(loc = "upper right")
+
+        # Preenchendo a área entre as curvas
+        plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - sigma, eixoY1 + erro_medio + sigma, color='gray', alpha=0.3)
+        plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - 2*sigma, eixoY1 + erro_medio + 2*sigma, color='gray', alpha=0.2)
+        plt.fill_between(np.arange(len(eixoY1)), eixoY1 + erro_medio - 3*sigma, eixoY1 + erro_medio + 3*sigma, color='gray', alpha=0.1)
+
+        # Adicionando o valor do desvio padrão ao canto superior esquerdo do gráfico
+        plt.text(0.025, 0.95, "sigma = {:.2f}".format(sigma) + ", average = {:.2f}".format(erro_medio), transform=plt.gca().transAxes, fontsize=12, verticalalignment='top')
+        
+        plt.show()
+
+
+
+
+
+
 #Plot correlation between calculated variables and objectives
 def PlotCorrelation(Calculated, Targeted):
 
@@ -117,6 +160,128 @@ def PlotCorrelation(Calculated, Targeted):
 
 
 
+
+
+
+#Plot correlation between calculated variables and objectives, com desvio padrão
+def PlotCorrelation2(Calculated, Targeted):
+
+    numdata,numevar = Calculated.shape
+    eixoX = np.arange(0, numdata, dtype=int)
+
+    for j in range(0,numevar):    
+        eixoY1= Targeted[:,j]
+        eixoY2= Calculated[:,j]        
+        coefcorrelacao = np.corrcoef(eixoY1,eixoY2)[1][0]
+        erro_medio = np.mean(eixoY2 - eixoY1)
+        sigma = np.std(eixoY2 - eixoY1)
+        valormax = np.max(eixoY1)
+        valormin = np.min(eixoY1)
+        
+        plt.title('Correlation coefficient variable '+ str(j+1)+' = ' + str(coefcorrelacao))
+        plt.scatter(eixoY1,eixoY2,color='blue',s=15,edgecolor='red') #grafico de correlação entre as variaveis procuradas e alvo---
+        plt.xlabel('Targeted')
+        plt.ylabel('Calculated')    
+
+        plt.plot([valormin,valormax], [valormin,valormax], color='black', alpha=0.9)
+        
+        plt.plot([valormin,valormax], [valormin+erro_medio-sigma,valormax+erro_medio-sigma], color='red', linestyle='dashed', alpha=0.5)
+        plt.plot([valormin,valormax], [valormin+erro_medio+sigma,valormax+erro_medio+sigma], color='red', linestyle='dashed', alpha=0.5)
+        
+        plt.plot([valormin,valormax], [valormin+erro_medio-2*sigma,valormax+erro_medio-2*sigma], color='green', linestyle='dashed', alpha=0.5)
+        plt.plot([valormin,valormax], [valormin+erro_medio+2*sigma,valormax+erro_medio+2*sigma], color='green', linestyle='dashed', alpha=0.5)
+
+        plt.plot([valormin,valormax], [valormin+erro_medio-3*sigma,valormax+erro_medio-3*sigma], color='blue', linestyle='dashed', alpha=0.5)
+        plt.plot([valormin,valormax], [valormin+erro_medio+3*sigma,valormax+erro_medio+3*sigma], color='blue', linestyle='dashed', alpha=0.5)
+        
+        plt.show()
+
+
+
+
+
+
+
+
+
+#Plota o erro em relação ao alvo,que é o centro do grafico
+def PlotDispe(Calculated, Targeted):
+
+    numdata,numevar = Calculated.shape
+    eixoX = np.arange(0, numdata, dtype=int)
+
+    for j in range(0,numevar):    
+        eixoY1 = Targeted[:,j]
+        eixoY2 = Calculated[:,j]     
+        erro = eixoY2 - eixoY1
+        
+        erro_medio = np.mean(eixoY2 - eixoY1)
+        sigma = np.std(eixoY2 - eixoY1)
+        
+        valormax = np.max(eixoY1)
+        valormin = np.min(eixoY1)
+        volormed =(valormin+valormax)/2
+        eixoY1norma = (eixoY1 - volormed)/(valormax - volormed)                        
+        
+        plt.scatter(eixoY1norma,erro,color='blue',s=15,edgecolor='red')
+        
+        plt.plot([-1,1], [0,0], color='black', alpha=0.9, linestyle='dashed')                
+
+        # Preenchendo a área entre as curvas
+        plt.fill_between((-1,1), erro_medio - sigma, erro_medio + sigma, color='gray', alpha=0.3)
+        plt.fill_between((-1,1), erro_medio - 2*sigma, erro_medio + 2*sigma, color='gray', alpha=0.2)
+        plt.fill_between((-1,1), erro_medio - 3*sigma, erro_medio + 3*sigma, color='gray', alpha=0.1)
+        
+        plt.title('Dispersion plot, 3 sigma colors, variable '+ str(j+1))
+        plt.xlabel('Variable normalized: -1,1')
+        plt.ylabel('Variable error (calculated-targeted)')
+        
+        plt.show()
+
+        
+
+
+
+
+
+
+
+#Plota o erro em relação ao alvo,que é o centro do grafico
+def PlotDispe2(Calculated, Targeted):
+
+    numdata,numevar = Calculated.shape
+    eixoX = np.arange(0, numdata, dtype=int)
+
+    for j in range(0,numevar):    
+        eixoY1 = Targeted[:,j]
+        eixoY2 = Calculated[:,j]
+
+        razao=  eixoY2/eixoY1
+        
+        eixoY3 = eixoY2 - eixoY1        
+        erro_medio = np.mean(eixoY2 - eixoY1)
+        sigma = np.std(eixoY2 - eixoY1)
+        eixoY4 = eixoY3/sigma
+        
+                        
+        plt.title('Target vs sniper, variable '+ str(j+1))
+        plt.scatter(eixoY4,razao,color='blue',s=15,edgecolor='red') #grafico de correlação entre as variaveis procuradas e alvo---
+        plt.xlabel('Standard deviation sigma')
+        plt.ylabel('Proportion = calculated/targeted')
+
+        plt.plot([-1,1], [1,1], color='black', alpha=0.9, linestyle='dashed')
+        plt.plot([0,0], [1-(np.max(razao)-1)*0.5,1+(np.max(razao)-1)*0.5], color='black', alpha=0.9, linestyle='dashed')
+        
+        plt.show()
+
+
+
+
+
+
+
+
+
 #Plota histograma do erro %
 def PlotHisto(Calculated, Targeted):
 
@@ -125,7 +290,8 @@ def PlotHisto(Calculated, Targeted):
     for j in range(0,numevar):    
         eixoY1= Targeted[:,j]
         eixoY2= Calculated[:,j]
-        eixoY3 = 100*(eixoY2 - eixoY1)/eixoY1 #erro percentual 0-100%
+        
+        eixoY3 = eixoY2 - eixoY1 #erro
 
         fig, ax = plt.subplots()
         
@@ -141,8 +307,8 @@ def PlotHisto(Calculated, Targeted):
         # place a text box in upper left in axes coords
         ax.text(0.05, 0.95, textstr, transform=ax.transAxes, fontsize=14, verticalalignment='top', bbox=props)
 
-        plt.title('Percent error histogram', fontsize=15)
-        plt.xlabel('Variable ' + str(j+1) + ', %', fontsize=12)
+        plt.title('Error histogram', fontsize=15)
+        plt.xlabel('Variable ' + str(j+1) , fontsize=12)
         plt.ylabel('Frequency', fontsize=12)
 
         plt.show()
